==> general_cli-0.0.11.tar.gz: template/web_template/lib/page/sign/sign_up.dart <==
import 'package:web_template/app/app_core.dart';
import 'package:web_template/widget/icon.dart';
import 'package:web_template/widget/switch.dart';
import 'package:flutter/material.dart';
import 'package:general_lib_flutter/general_lib_flutter_core.dart';
import 'package:line_icons/line_icons.dart';

class SignUpPage extends StatefulWidget {
  final AppCore appCore;

  const SignUpPage({super.key, required this.appCore});
  @override
  State<SignUpPage> createState() => _SignUpPageState();
}

class _SignUpPageState extends State<SignUpPage> {
  TextEditingController usernameTextEditingController = TextEditingController();
  TextEditingController passwordTextEditingController = TextEditingController();
  @override
  void initState() {
    super.initState();

    WidgetsBinding.instance.addPostFrameCallback((Duration duration) async {});
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    print(context.orientation);
    return Scaffold(
      body: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          const Padding(
            padding: EdgeInsets.all(10),
            child: Text(
              "Sign Up",
              style: TextStyle(
                fontSize: 30,
                fontWeight: FontWeight.bold,
              ),
            ),
          ),
          const Padding(
            padding: EdgeInsets.all(10),
            child: Text(
              "Untuk melakukan ini pastikan anda sudah membaca terms dan conditions dahulu ya",
              style: TextStyle(
                fontSize: 10,
                fontWeight: FontWeight.normal,
              ),
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(10),
            child: ThemeToggleSwitch(
              appCore: widget.appCore,
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(5),
            child: textFormField(
              controller: usernameTextEditingController,
              labelText: "Username",
              hintText: "username",
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(5),
            child: textFormField(
              controller: passwordTextEditingController,
              labelText: "Password",
              hintText: "username",
              prefixIconData: Icons.key,
            ),
          ),
          Container(
            margin: const EdgeInsets.all(5),
            width: context.width,
            decoration: BoxDecoration(
              color: Colors.blue,
              borderRadius: const BorderRadius.all(Radius.circular(25)),
              boxShadow: [
                BoxShadow(
                  color: context.theme.shadowColor.withAlpha(110),
                  spreadRadius: 1,
                  blurRadius: 7,
                  offset: const Offset(0, 3), // changes position of shadow
                ),
                BoxShadow(
                  color: context.theme.shadowColor.withAlpha(110),
                  spreadRadius: 1,
                  blurRadius: 7,
                  offset: const Offset(0, 3), // changes position of shadow
                ),
              ],
            ),
            clipBehavior: Clip.antiAlias,
            child: MaterialButton(
              minWidth: 0,
              onPressed: () {},
              padding: const EdgeInsets.all(20),
              child: const Text(
                "Sign Up",
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 20,
                  fontWeight: FontWeight.bold,
                ),
              ),
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(5),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                IconWidget(
                  iconData: LineIcons.github,
                  onPressed: () {},
                ),
                IconWidget(
                  iconData: LineIcons.telegram,
                  onPressed: () {},
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }

  Widget textFormField({String? hintText, String? labelText, IconData prefixIconData = Icons.people, Color color = Colors.white, TextEditingController? controller, String? Function(String? data)? validator, bool readOnly = false, bool obscureText = false}) {
    return TextFormField(
      cursorColor: context.theme.indicatorColor,
      controller: controller,
      autovalidateMode: AutovalidateMode.onUserInteraction,
      validator: validator,
      readOnly: readOnly,
      obscureText: obscureText,
      style: const TextStyle(
          // color: Colors.black,
          ),
      onChanged: (value) {
        setState(() {});
      },
      decoration: InputDecoration(
        contentPadding: const EdgeInsets.all(0.0),
        hintText: hintText,
        labelText: labelText,
        labelStyle: context.theme.textTheme.labelSmall,
        hintStyle: const TextStyle(
          // color: Colors.grey,
          fontSize: 14.0,
        ),
        prefixIcon: Icon(
          prefixIconData,
          color: context.theme.primaryIconTheme.color,
          size: 18,
        ),
        disabledBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.focusColor,
            width: 2,
          ),
          borderRadius: BorderRadius.circular(10.0),
        ),
        enabledBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.focusColor,
            width: 2.5,
          ),
          borderRadius: BorderRadius.circular(10.0),
        ),
        floatingLabelStyle: context.theme.textTheme.labelMedium,
        focusedErrorBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.focusColor,
            width: 1.5,
          ),
          borderRadius: BorderRadius.circular(15.0),
        ),
        errorBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.focusColor,
            width: 1.5,
          ),
          borderRadius: BorderRadius.circular(15.0),
        ),
        focusedBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.indicatorColor,
            width: 1.5,
          ),
          borderRadius: BorderRadius.circular(15.0),
        ),
      ),
    );
  }
}

==> general_cli-0.0.13.tar.gz: template/web_template/lib/page/sign/sign_up.dart <==
import 'package:web_template/app/app_core.dart';
import 'package:web_template/widget/icon.dart';
import 'package:web_template/widget/switch.dart';
import 'package:flutter/material.dart';
import 'package:general_lib_flutter/general_lib_flutter_core.dart';
import 'package:line_icons/line_icons.dart';

class SignUpPage extends StatefulWidget {
  final AppCore appCore;

  const SignUpPage({super.key, required this.appCore});
  @override
  State<SignUpPage> createState() => _SignUpPageState();
}

class _SignUpPageState extends State<SignUpPage> {
  TextEditingController usernameTextEditingController = TextEditingController();
  TextEditingController passwordTextEditingController = TextEditingController();
  @override
  void initState() {
    super.initState();

    WidgetsBinding.instance.addPostFrameCallback((Duration duration) async {});
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    print(context.orientation);
    return Scaffold(
      body: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          const Padding(
            padding: EdgeInsets.all(10),
            child: Text(
              "Sign Up",
              style: TextStyle(
                fontSize: 30,
                fontWeight: FontWeight.bold,
              ),
            ),
          ),
          const Padding(
            padding: EdgeInsets.all(10),
            child: Text(
              "Untuk melakukan ini pastikan anda sudah membaca terms dan conditions dahulu ya",
              style: TextStyle(
                fontSize: 10,
                fontWeight: FontWeight.normal,
              ),
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(10),
            child: ThemeToggleSwitch(
              appCore: widget.appCore,
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(5),
            child: textFormField(
              controller: usernameTextEditingController,
              labelText: "Username",
              hintText: "username",
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(5),
            child: textFormField(
              controller: passwordTextEditingController,
              labelText: "Password",
              hintText: "username",
              prefixIconData: Icons.key,
            ),
          ),
          Container(
            margin: const EdgeInsets.all(5),
            width: context.width,
            decoration: BoxDecoration(
              color: Colors.blue,
              borderRadius: const BorderRadius.all(Radius.circular(25)),
              boxShadow: [
                BoxShadow(
                  color: context.theme.shadowColor.withAlpha(110),
                  spreadRadius: 1,
                  blurRadius: 7,
                  offset: const Offset(0, 3), // changes position of shadow
                ),
                BoxShadow(
                  color: context.theme.shadowColor.withAlpha(110),
                  spreadRadius: 1,
                  blurRadius: 7,
                  offset: const Offset(0, 3), // changes position of shadow
                ),
              ],
            ),
            clipBehavior: Clip.antiAlias,
            child: MaterialButton(
              minWidth: 0,
              onPressed: () {},
              padding: const EdgeInsets.all(20),
              child: const Text(
                "Sign Up",
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 20,
                  fontWeight: FontWeight.bold,
                ),
              ),
            ),
          ),
          Padding(
            padding: const EdgeInsets.all(5),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                IconWidget(
                  iconData: LineIcons.github,
                  onPressed: () {},
                ),
                IconWidget(
                  iconData: LineIcons.telegram,
                  onPressed: () {},
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }

  Widget textFormField(
      {String? hintText,
      String? labelText,
      IconData prefixIconData = Icons.people,
      Color color = Colors.white,
      TextEditingController? controller,
      String? Function(String? data)? validator,
      bool readOnly = false,
      bool obscureText = false}) {
    return TextFormField(
      cursorColor: context.theme.indicatorColor,
      controller: controller,
      autovalidateMode: AutovalidateMode.onUserInteraction,
      validator: validator,
      readOnly: readOnly,
      obscureText: obscureText,
      style: const TextStyle(
          // color: Colors.black,
          ),
      onChanged: (value) {
        setState(() {});
      },
      decoration: InputDecoration(
        contentPadding: const EdgeInsets.all(0.0),
        hintText: hintText,
        labelText: labelText,
        labelStyle: context.theme.textTheme.labelSmall,
        hintStyle: const TextStyle(
          // color: Colors.grey,
          fontSize: 14.0,
        ),
        prefixIcon: Icon(
          prefixIconData,
          color: context.theme.primaryIconTheme.color,
          size: 18,
        ),
        disabledBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.focusColor,
            width: 2,
          ),
          borderRadius: BorderRadius.circular(10.0),
        ),
        enabledBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.focusColor,
            width: 2.5,
          ),
          borderRadius: BorderRadius.circular(10.0),
        ),
        floatingLabelStyle: context.theme.textTheme.labelMedium,
        focusedErrorBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.focusColor,
            width: 1.5,
          ),
          borderRadius: BorderRadius.circular(15.0),
        ),
        errorBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.focusColor,
            width: 1.5,
          ),
          borderRadius: BorderRadius.circular(15.0),
        ),
        focusedBorder: OutlineInputBorder(
          borderSide: BorderSide(
            color: context.theme.indicatorColor,
            width: 1.5,
          ),
          borderRadius: BorderRadius.circular(15.0),
        ),
      ),
    );
  }
}
